@@ -1,3 +1,4 @@
+import os
 import unittest
 import numpy as np
 from omnixai.utils.misc import set_random_seed
@@ -39,6 +40,16 @@ class TestShapTimeseries(unittest.TestCase):
         self.assertAlmostEqual(cf[1], 0.049, delta=1e-3)
         self.assertAlmostEqual(cf[2], 0.149, delta=1e-3)
 
+        base_folder = os.path.dirname(os.path.abspath(__file__))
+        directory = f"{base_folder}/../../datasets/tmp"
+        explainer.save(directory=directory)
+        explainer = CounterfactualExplainer.load(directory=directory)
+        explanations = explainer.explain(self.test_data)
+        cf = explanations.get_explanations(index=0)["counterfactual"]["x"].values
+        self.assertEqual(cf[0], 0.0)
+        self.assertAlmostEqual(cf[1], 0.049, delta=1e-3)
+        self.assertAlmostEqual(cf[2], 0.149, delta=1e-3)
+
 
 if __name__ == "__main__":
     unittest.main()
